// SPDX-License-Identifier: GPL-2.0
#include "TabBase.h"

TabBase::TabBase(QWidget *parent) : QWidget(parent)
{
}

void TabBase::updateUi(QString titleColor)
{
	Q_UNUSED(titleColor)
}
